
# Setup -------------------------------------------------------------------

# Load packages
library(psych)
library(tidyverse)
library(tidystats)
library(lme4)
library(lmerTest)
library(apaTables)
library(cocor)
library(ggeffects)
library(ppcor)
library(lavaan)

# Set options
options(scipen = 999)

# Load data
study1 <- read_csv("data/prepared data study 1.csv")
study2 <- read_csv("data/prepared data study 2.csv")
study3 <- read_csv("data/prepared data study 3.csv")

# Add study information
study1 <- mutate(study1, study = 1)
study2 <- mutate(study2, study = 2)
study3 <- mutate(study3, study = 3)

# Combine data
data <- bind_rows(study1, study2, study3)
glimpse(data)

# Select columns of interest
data <- dplyr::select(data, ID, study, pseudo_profound_bullshit, scientific_bullshit, 
  scientific_facts, scientific_bullshit_detection, belief_in_science, 
  science_literacy, social_conservatism, economic_conservatism, 
  free_market_belief, faith_in_intuition, need_for_cognition, openness, 
  extraversion, conscientiousness, agreeableness, neuroticism, acquiescence, 
  gender, age, ethnicity, language, education, income)

# Set options
options(scipen = 999)

# Exclusions --------------------------------------------------------------

# Total N
nrow(data)

# Exclude participants who did not fill out the bullshit measures
data <- filter(data, !is.na(pseudo_profound_bullshit) & 
    !is.na(scientific_bullshit))
nrow(data)

# And those who did not fill in any of the non-bullshit questionnaires
data <- filter(data, (is.na(belief_in_science) + is.na(social_conservatism) + 
    is.na(economic_conservatism) + is.na(free_market_belief) + 
    is.na(faith_in_intuition) + is.na(need_for_cognition) + is.na(openness) + 
    is.na(extraversion) + is.na(conscientiousness) + is.na(agreeableness) + 
    is.na(neuroticism) + is.na(science_literacy)
  ) != 12) 

# Final N
nrow(data)

# excluded participants
2039-1948
91/2039

# Analysis preparation ----------------------------------------------------

# Create the education category variable
data <- mutate(data, education_category = case_when(
    education == "some high school" ~ "high school",
    education == "high school diploma or equivalent" ~ "high school",
    education == "some college" ~ "college",
    education == "college degree" ~ "college",
    education == "some graduate school" ~ "graduate school",
    education == "graduate degree" ~ "graduate school")
  )

# Set the reference categories
data <- mutate(data, 
    education_category = fct_relevel(education_category, "high school"),
    gender = fct_relevel(gender, "male")
  )

# Data analysis -----------------------------------------------------------

# Descriptive statistics

# Sample size
data %>% 
  group_by(study) %>%
  summarize(n = n())

# Gender
data %>% 
  count(study, gender) %>%
  group_by(study)
data %>% 
  count(gender)

# Age
data %>% 
  group_by(study) %>%
  summarize(age_m = mean(age, na.rm=TRUE),
            age_sd = sd(age, na.rm=TRUE))
data %>% 
  summarize(age_m = mean(age, na.rm=TRUE),
            age_sd = sd(age, na.rm=TRUE))

# Education level
data %>% 
  count(study, education_category) %>%
  group_by(study)
data %>% 
  count(education_category)

# compute means and sds for remaining vars
means <- data %>%
  dplyr::select(pseudo_profound_bullshit, scientific_bullshit, scientific_facts, scientific_bullshit_detection,
         belief_in_science, social_conservatism, economic_conservatism,
         free_market_belief, faith_in_intuition, need_for_cognition) %>%
  summarise_all(list(mean=mean), na.rm=TRUE)
print(means)

sds <- data %>%
  dplyr::select(pseudo_profound_bullshit, scientific_bullshit, scientific_facts, scientific_bullshit_detection,
         belief_in_science, social_conservatism, economic_conservatism,
         free_market_belief, faith_in_intuition, need_for_cognition) %>%
  summarise_all(list(sd=sd), na.rm=TRUE)
print(sds)

# confirmatory factor analyses
data_full <- bind_rows(study1, study2, study3)
data_cfa <- dplyr::select(data_full, PPBRS_1:PPBRS_10, contains("SBR_bullshit"))

## estimate a one variable CFA model
cfa.1factor <- ' bullshit  =~ SBR_bullshit_1 + SBR_bullshit_2 + SBR_bullshit_3 + SBR_bullshit_4 + 
                         SBR_bullshit_5 + SBR_bullshit_6 + SBR_bullshit_7 + SBR_bullshit_8 +
                         SBR_bullshit_9 + SBR_bullshit_10 + PPBRS_1 + PPBRS_2 + PPBRS_3 + PPBRS_4 + PPBRS_5 + PPBRS_6+ PPBRS_7 +
                        PPBRS_8 + PPBRS_9 + PPBRS_10'
fit1 <- cfa(cfa.1factor, data=data_cfa)
summary(fit1, fit.measures=TRUE)

## estimate a two variable CFA model
cfa.2factor <- ' sbr  =~ SBR_bullshit_1 + SBR_bullshit_2 + SBR_bullshit_3 + SBR_bullshit_4 + 
                         SBR_bullshit_5 + SBR_bullshit_6 + SBR_bullshit_7 + SBR_bullshit_8 +
                         SBR_bullshit_9 + SBR_bullshit_10
              ppbr =~ PPBRS_1 + PPBRS_2 + PPBRS_3 + PPBRS_4 + PPBRS_5 + PPBRS_6+ PPBRS_7 +
                      PPBRS_8 + PPBRS_9 + PPBRS_10'
fit2 <- cfa(cfa.2factor, data=data_cfa)
summary(fit2, fit.measures=TRUE)

## compare the fit of the one-variable and two-variable models
anova(fit2, fit1)

# alpha calculations for BS receptivity measures and belief in science
data_ppbr <- dplyr::select(data_full, PPBRS_1:PPBRS_20)
psych::alpha(data_ppbr)
data_sbr <- dplyr::select(data_full, contains("SBR_bullshit"))
psych::alpha(data_sbr)
data_bis <- dplyr::select(data_full, BS_1:BS_9)
psych::alpha(data_bis)

# estimate correlations of BS receptivity, belief in science, ideology measures, and cognitive style
data.cor <- data %>%
  dplyr::select(scientific_bullshit, pseudo_profound_bullshit, belief_in_science, social_conservatism, economic_conservatism, free_market_belief, faith_in_intuition, need_for_cognition)
corr.test(data.cor)
p.table <- corr.test(data.cor)$p
ci.list <- corr.test(data.cor)$ci

# Belief in science and bullshit
M_PPBS_BiS <- cor.test(data$pseudo_profound_bullshit, data$belief_in_science)
M_SBS_BiS <- cor.test(data$scientific_bullshit, data$belief_in_science)
M_PPBS_SBS <- cor.test(data$scientific_bullshit, data$pseudo_profound_bullshit)
M_PPBS_BiS
M_SBS_BiS
M_PPBS_SBS
cocor.dep.groups.overlap(M_PPBS_BiS$estimate, 
                         M_SBS_BiS$estimate, 
                         M_PPBS_SBS$estimate, 
                         n = 1948)

# Social conservatism and bullshit
M_PPBS_SC <- cor.test(data$pseudo_profound_bullshit, data$social_conservatism)
M_SBS_SC <- cor.test(data$scientific_bullshit, data$social_conservatism)
M_PPBS_SBS <- cor.test(data$scientific_bullshit, data$pseudo_profound_bullshit)
M_PPBS_SC
M_SBS_SC
M_PPBS_SBS
cocor.dep.groups.overlap(M_PPBS_SC$estimate, 
                         M_SBS_SC$estimate, 
                         M_PPBS_SBS$estimate, 
                         n = 1948)

# Economic conservatism and bullshit
M_PPBS_EC <- cor.test(data$pseudo_profound_bullshit, data$economic_conservatism)
M_SBS_EC <- cor.test(data$scientific_bullshit, data$economic_conservatism)
M_PPBS_SBS <- cor.test(data$scientific_bullshit, data$pseudo_profound_bullshit)
M_PPBS_EC
M_SBS_EC
M_PPBS_SBS
cocor.dep.groups.overlap(M_PPBS_EC$estimate, 
                         M_SBS_EC$estimate, 
                         M_PPBS_SBS$estimate, 
                         n = 1948)

# Free market beliefs and bullshit
M_PPBS_FMB <- cor.test(data$pseudo_profound_bullshit, data$free_market_belief)
M_SBS_FMB <- cor.test(data$scientific_bullshit, data$free_market_belief)
M_PPBS_SBS <- cor.test(data$scientific_bullshit, data$pseudo_profound_bullshit)
M_PPBS_FMB
M_SBS_FMB
cocor.dep.groups.overlap(M_PPBS_FMB$estimate, 
                         M_SBS_FMB$estimate, 
                         M_PPBS_SBS$estimate, 
                         n = 365)

# faith in intuition and bullshit
M_PPBS_FI <- cor.test(data$pseudo_profound_bullshit, data$faith_in_intuition)
M_SBS_FI <- cor.test(data$scientific_bullshit, data$faith_in_intuition)
M_PPBS_SBS <- cor.test(data$scientific_bullshit, data$pseudo_profound_bullshit)
M_PPBS_FI
M_SBS_FI
cocor.dep.groups.overlap(M_PPBS_FI$estimate, 
                         M_SBS_FI$estimate, 
                         M_PPBS_SBS$estimate, 
                         n = 543)

# Need for cognition and bullshit
M_PPBS_NFC <- cor.test(data$pseudo_profound_bullshit, data$need_for_cognition)
M_SBS_NFC <- cor.test(data$scientific_bullshit, data$need_for_cognition)
M_PPBS_SBS <- cor.test(data$scientific_bullshit, data$pseudo_profound_bullshit)
M_PPBS_NFC
M_SBS_NFC
cocor.dep.groups.overlap(M_PPBS_NFC$estimate, 
                         M_SBS_NFC$estimate, 
                         M_PPBS_SBS$estimate, 
                         n = 543)

# Acquiescence and bullshit
M_PPBS_ACQ <- cor.test(data$pseudo_profound_bullshit, data$acquiescence)
M_SBS_ACQ <- cor.test(data$scientific_bullshit, data$acquiescence)
M_PPBS_ACQ
M_SBS_ACQ

# Acquiescence, belief in science and ideology
M_BiS_ACQ <- cor.test(data$belief_in_science, data$acquiescence)
M_SC_ACQ <- cor.test(data$social_conservatism, data$acquiescence)
M_EC_ACQ <- cor.test(data$economic_conservatism, data$acquiescence)
M_BiS_ACQ
M_SC_ACQ
M_EC_ACQ

# acquiescence and cognitive style
M_FI_ACQ <- cor.test(data$faith_in_intuition, data$acquiescence)
M_NFC_ACQ <- cor.test(data$need_for_cognition, data$acquiescence)
M_FI_ACQ
M_NFC_ACQ

# correlations with acquiescence controlled for

## select study 2 observations with valid acquiescence scores
data_study2 <- subset(data, is.na(acquiescence)==FALSE)

## regress the two types of bullshit on acquiescence, and save model residuals
model_sbs_acq <- lm(scientific_bullshit~acquiescence, data_study2)
summary(model_sbs_acq)
model_ppbs_acq <- lm(pseudo_profound_bullshit~acquiescence, data_study2)
summary(model_ppbs_acq)
data_study2$scientific_bullshit_acq <- residuals(model_sbs_acq)
data_study2$pseudo_profound_acq <- residuals(model_ppbs_acq)

## estimate semi-partial correlations of bullshit receptivity
data.cor_acq <- data_study2 %>%
  dplyr::select(scientific_bullshit_acq, pseudo_profound_acq, belief_in_science, social_conservatism, economic_conservatism, faith_in_intuition, need_for_cognition)
corr_table_acq <- corr.test(data.cor_acq)
corr_table2_acq <- corr_table_acq$ci[2:11,1:3]

## estimate comparable zero-order correlations of bullshit receptivity
data.cor_zero <- data_study2 %>%
  dplyr::select(scientific_bullshit, pseudo_profound_bullshit, belief_in_science, social_conservatism, economic_conservatism, faith_in_intuition, need_for_cognition)
corr_table_zero <- corr.test(data.cor_zero)
corr_table2_zero <- corr_table_zero$ci[2:11,1:3]

## label table of correlations
corr_table2_zero$corr_type <- "Zero-order"
corr_table2_acq$corr_type <- "Semi-partial"
corr_table2_zero$bs_type <- "Scientific bullshit"
corr_table2_zero[6:10,]$bs_type <- "Pseudo profound bullshit"
corr_table2_acq$bs_type <- "Scientific bullshit"
corr_table2_acq[6:10,]$bs_type <- "Pseudo profound bullshit"
corr_table3 <-rbind(corr_table2_zero, corr_table2_acq)
variable_names <- rep(c("Belief in science", "Social conservatism",
                      "Economic conservatism",
                      "Faith in intuition", "Need for cognition"), 4)
corr_table3$variable_name <- variable_names

## compare zero order and semi partial correlations
bs_cor_sci <- cor.test(data_study2$scientific_bullshit_acq, data_study2$scientific_bullshit)$estimate
bs_cor_pp<- cor.test(data_study2$pseudo_profound_acq, data_study2$pseudo_profound_bullshit)$estimate
zero_cor <- corr_table2_zero$r
acq_cor <- corr_table2_acq$r

for (i in 1:5) {
cor_a <- zero_cor[i]
cor_b <- acq_cor[i]
print(cocor.dep.groups.overlap(cor_a, cor_b, bs_cor_sci, n = 543))
}
for (i in 6:10) {
  cor_a <- zero_cor[i]
  cor_b <- acq_cor[i]
  print(cocor.dep.groups.overlap(cor_a, cor_b, bs_cor_pp, n = 543))
}

# estimate whether science literacy moderates the relationship between ppbs and sbs
data$sbs_z <- as.numeric(scale(data$scientific_bullshit))
data$ppbs_z <- as.numeric(scale(data$pseudo_profound_bullshit))
data$sl_z <- as.numeric(scale(data$science_literacy))
model5 <- lm(sbs_z~ppbs_z + sl_z + ppbs_z*sl_z, data=data)
summary(model5)

# correlations including scientific facts and bullshit sensitivity
detection_vars <- subset(data, study != 3)
detection_vars <- detection_vars[,c(4:6,3,7, 9:13)]
detection_vars <- subset(detection_vars, !(is.na(scientific_facts)))
corr_table_detection <- corr.test(detection_vars)
detection_r <- corr_table_detection$r
detection_ci <- corr_table_detection$ci

# Figures -------------------------------------------------------------------

# figure comparing scientific and profound correlation coefficients (Figure 1)
corr_table <- corr.test(data.cor)
corr_table2 <- corr_table$ci[2:13,1:3]
corr_table2$bs_type <- "Scientific"
corr_table2[7:12,]$bs_type <- "Pseudo profound"
variable_names <- c("Belief in science", "Social conservatism",
                    "Economic conservatism", "Free market beliefs",
                    "Faith in intuition", "Need for cognition",
                    "Belief in science", "Social conservatism",
                    "Economic conservatism", "Free market beliefs",
                    "Faith in intuition", "Need for cognition")
corr_table2$variable_name <- variable_names
corr_table2$variable_name <- factor(corr_table2$variable_name,
                          levels = c("Need for cognition", "Faith in intuition",
                                     "Free market beliefs", "Economic conservatism",
                                     "Social conservatism", "Belief in science"),
                          labels = c("Need for cognition", "Faith in intuition",
                                     "Free market beliefs", "Economic conservatism",
                                     "Social conservatism", "Belief in science"))

plot1 <- ggplot(corr_table2, aes(x=variable_name, y=r, color=bs_type)) +
  geom_point(position=position_dodge(width=.5)) +
  geom_errorbar(aes(ymin=lower, ymax=upper),position=position_dodge(width=.5), width=.5) +
  coord_flip() +
  theme_bw(base_size = 20) +  
  xlab("") +
  ylab("Correlation") +
  labs(color = "Type of bullshit") +
  guides(color = guide_legend(reverse=TRUE))
plot1

# figure comparing zero order and semi partial correlations (Figure 2)
corr_table3$variable_name <- factor(corr_table3$variable_name,
                                    levels = c("Need for cognition", "Faith in intuition",
                                               "Economic conservatism",
                                               "Social conservatism", "Belief in science"),
                                    labels = c("Need for cognition", "Faith in intuition",
                                               "Economic conservatism",
                                               "Social conservatism", "Belief in science"))

plot2 <- ggplot(corr_table3, aes(x=variable_name, y=r, color=corr_type)) +
  geom_point(position=position_dodge(width=.5)) +
  geom_errorbar(aes(ymin=lower, ymax=upper),position=position_dodge(width=.5), width=.5) +
  coord_flip() +
  theme_bw(base_size = 20) +  
  xlab("") +
  ylab("Correlation") +
  labs(color = "Type of correlation") +
  facet_wrap(~bs_type) +
  guides(color = guide_legend(reverse=TRUE))
plot2

# plot the interaction between the two types of bullshit receptivity and science literacy (Figure 3)
predicted <- ggpredict(model5, terms = c("ppbs_z[-1, 0, 1]", "sl_z[-1, 0, 1]"))
predicted$group <- factor(predicted$group,
                          levels = c(-1, 0, 1),
                          labels = c("Low (-1SD)", "Medium (Mean)", "High (+1SD)"))

plot2 <- ggplot(predicted, aes(x=x, y=predicted, color=group)) +
  geom_line(size=1.5) +
  geom_ribbon(aes(ymin=conf.low, ymax=conf.high), linetype=2, alpha=0.1) +
  xlab("Pseudo profound bullshit receptivity ") +
  ylab("Scientific bullshit receptivity") +
  labs(color = "Scientific literacy") +
  theme_bw(base_size = 20)
plot2