
# Setup ---------------------------------------------------------------------------------------

# Load packages
library(tidyverse)

# Read data
data <- read_csv("Data/scientific BS study 1_March 20, 2018_14.37.csv")
glimpse(data)

# Prepare data --------------------------------------------------------------------------------

# Create an ID variable
data$ID <- 1:nrow(data)

# Remove the first 3 rows of data (these reflecting tests done by the experimenter)
data <- filter(data, ID > 3)

# Remove variables that are not of interest
data <- select(data, -Status, -IPAddress, -Progress, -Finished, -RecordedDate, -ResponseId, 
               -RecipientLastName, -RecipientFirstName, -RecipientEmail, -ExternalReference, 
               -LocationLatitude, -LocationLongitude, -DistributionChannel)

# Rename some variables
data <- data %>% 
  rename(
    start_date = StartDate,
    end_date = EndDate,
    duration = `Duration (in seconds)`,
    
    FMB_2 = `FMB_2 (R)`,
    FMB_4 = `FMB_4 (R)`,
    FMB_5 = `FMB_5 (R)`,
    FMB_6 = `FMB_6 (R)`,
    
    SECS_social_1 = SECS_1, 
    SECS_social_6 = SECS_6, 
    SECS_social_7 = SECS_7, 
    SECS_social_9 = SECS_9, 
    SECS_social_10 = SECS_10, 
    SECS_social_13 = SECS_13, 
    SECS_social_14 = SECS_14,
    
    SECS_economic_2 = SECS_2, 
    SECS_economic_5 = SECS_5, 
    SECS_economic_8 = SECS_8, 
    SECS_economic_11 = SECS_11, 
    SECS_economic_12 = SECS_12, 
    
    government_trust = GovTrust,
    democratic_trust = DemTrust,
    republican_trust = RepTrust,
    political_orientation = PolIdent,
    political_orientation_other = PolIdent_5_TEXT,
    gender = Gender,
    age = Age,
    ethnicity = ethnic,
    education = edu,
    comments = cmmnts
  )

names(data) <- str_replace(names(data), "Real", "fact")
names(data) <- str_replace(names(data), "Bull", "bullshit")
names(data) <- str_replace(names(data), "BSS_BSS", "BS")

# Reverse score some of the items
# Free market belief
data$FMB_2 <- 6 - data$FMB_2
data$FMB_4 <- 6 - data$FMB_4
data$FMB_5 <- 6 - data$FMB_5
data$FMB_6 <- 6 - data$FMB_6

# Social economic conservatism scale
data$SECS_social_1 <- 100 - data$SECS_social_1
data$SECS_economic_2 <- 100 - data$SECS_economic_2

# Create extremism responses for the political conservatism measures
data$SECS_extremism_social_1 = abs(50 - data$SECS_social_1)
data$SECS_extremism_social_6 = abs(50 - data$SECS_social_6) 
data$SECS_extremism_social_7 = abs(50 - data$SECS_social_7) 
data$SECS_extremism_social_9 = abs(50 - data$SECS_social_9)
data$SECS_extremism_social_10 = abs(50 - data$SECS_social_10) 
data$SECS_extremism_social_13 = abs(50 - data$SECS_social_13) 
data$SECS_extremism_social_14 = abs(50 - data$SECS_social_14)

data$SECS_extremism_economic_2 = abs(50 - data$SECS_economic_2) 
data$SECS_extremism_economic_5 = abs(50 - data$SECS_economic_5) 
data$SECS_extremism_economic_8 = abs(50 - data$SECS_economic_8)
data$SECS_extremism_economic_11 = abs(50 - data$SECS_economic_11) 
data$SECS_extremism_economic_12 = abs(50 - data$SECS_economic_12)

data$FMB_extremism_1 <- abs(3 - data$FMB_1)
data$FMB_extremism_2 <- abs(3 - data$FMB_2)
data$FMB_extremism_3 <- abs(3 - data$FMB_3)
data$FMB_extremism_4 <- abs(3 - data$FMB_4)
data$FMB_extremism_5 <- abs(3 - data$FMB_5)
data$FMB_extremism_6 <- abs(3 - data$FMB_6)

# Calculate mean scores of the scales
data$pseudo_profound_bullshit <- rowMeans(select(data, starts_with("PPBRS")))
data$scientific_bullshit <- rowMeans(select(data, starts_with("SBR_bullshit")))
data$scientific_facts <- rowMeans(select(data, starts_with("SBR_fact")))
data$belief_in_science <- rowMeans(select(data, starts_with("BS")))
data$social_conservatism <- rowMeans(select(data, starts_with("SECS_social")))
data$economic_conservatism <- rowMeans(select(data, starts_with("SECS_economic")))
data$free_market_belief <- rowMeans(select(data, starts_with("FMB"), -starts_with("FMB_extremism")))

# Calculate political extremism scores
data$social_conservatism_extremism <- rowMeans(select(data, starts_with("SECS_extremism_social")))
data$economic_conservatism_extremism <- rowMeans(select(data, 
                                                        starts_with("SECS_extremism_economic")))
data$free_market_belief_extremism <- rowMeans(select(data, starts_with("FMB_extremism")))

# Calculate a scientific bullshit detection score
data$scientific_bullshit_detection <- data$scientific_facts - data$scientific_bullshit

# Fix age (1 person accidentally entered 'white')
data$age <- as.numeric(data$age)

# Create labels for some of the variables
data$gender <- factor(data$gender, labels = c("male", "female", "other"))
data$education <- factor(data$education, 
                         labels = c("some high school", "high school diploma or equivalent", 
                                    "some college", "college degree", "some graduate school",
                                    "graduate degree"))
data$income <- factor(data$income, labels = c("less than $10,000 per year", "$10,001 - $25,000",
                                              "$25,001 - $40,000", "$40,001 - $55,000",
                                              "$55,001 - $70,000", "$70,001 - $85,000",
                                              "$85,001 - $100,000", "over $100,000"))
data$political_orientation <- factor(data$political_orientation, 
                                     labels = c("democrat", "republican", "libertarian", 
                                                "independent", "other"))

# Save data -----------------------------------------------------------------------------------

write_csv(data, "Data/prepared data study 1.csv", na = "")

