
# Setup ---------------------------------------------------------------------------------------

# Load packages
library(tidyverse)

# Read data
data <- read_csv("Data/Scientific BS Study 2_March 27, 2018_15.48.csv")

# Prepare data --------------------------------------------------------------------------------

# Remove testing data
data <- filter(data, Status == 0)

# Create an ID variable
data$ID <- 1:nrow(data)

# Remove ID number 1 (this was Tony)
data <- filter(data, ID != 1)

# Remove variables that are not of interest
data <- select(data, -Status, -IPAddress, -Progress, -Finished, -RecordedDate, -ResponseId, 
               -RecipientLastName, -RecipientFirstName, -RecipientEmail, -ExternalReference, 
               -LocationLatitude, -LocationLongitude, -DistributionChannel)

# Rename variables
data <- data %>%
  rename(
    start_date = StartDate,
    end_date = EndDate,
    duration = `Duration (in seconds)`,
    
    BFI_E_negative = BFI_BFI_1,
    BFI_A_positive = BFI_BFI_2,
    BFI_C_negative = BFI_BFI_3,
    BFI_N_positive = BFI_BFI_4,
    BFI_O_negative = BFI_BFI_5,
    BFI_E_positive = BFI_BFI_6,
    BFI_A_negative = BFI_BFI_7,
    BFI_C_positive = BFI_BFI_8,
    BFI_N_negative = BFI_BFI_9,
    BFI_O_positive = BFI_BFI_10,
  
    SECS_social_1 = SECS_1,
    SECS_social_6 = SECS_6,
    SECS_social_7 = SECS_7,
    SECS_social_9 = SECS_9,
    SECS_social_10 = SECS_10,
    SECS_social_13 = SECS_13,
    SECS_social_14 = SECS_14,
    
    SECS_economic_2 = SECS_2,
    SECS_economic_5 = SECS_5,
    SECS_economic_8 = SECS_8,
    SECS_economic_11 = SECS_11,
    SECS_economic_12 = SECS_12,
    
    government_trust = GovTrust,
    democratic_trust = DemTrust,
    republican_trust = RepTrust,
    political_orientation = PolIdent,
    political_orientation_other = PolIdent_5_TEXT,
    gender = Gender,
    age = Age,
    ethnicity = ethnic,
    language = UserLanguage,
    education = edu,
    comments = cmmnts
  )

names(data) <- str_replace(names(data), "Real", "fact")
names(data) <- str_replace(names(data), "Bull", "bullshit")
names(data) <- str_replace(names(data), "BSS_BSS", "BS")

# Reverse score some of the items

# Need for cognition
data <- data %>%
  mutate(
    NFC_3 = 6 - NFC_3_R,
    NFC_4 = 6 - NFC_4_R,
    NFC_5 = 6 - NFC_5_R,
    NFC_7 = 6 - NFC_7_R,
    NFC_8 = 6 - NFC_8_R,
    NFC_9 = 6 - NFC_9_R,
    NFC_12 = 6 - NFC_12_R,
    NFC_16 = 6 - NFC_16_R,
    NFC_17 = 6 - NFC_17_R
  )

# Remove non-reverse coded columns
data <- select(data, -ends_with("_R"))

# Social economic conservatism scale
data$SECS_social_1 <- 100 - data$SECS_social_1
data$SECS_economic_2 <- 100 - data$SECS_economic_2

# Create extremism responses for the political conservatism measures
data$SECS_extremism_social_1 = abs(50 - data$SECS_social_1)
data$SECS_extremism_social_6 = abs(50 - data$SECS_social_6) 
data$SECS_extremism_social_7 = abs(50 - data$SECS_social_7) 
data$SECS_extremism_social_9 = abs(50 - data$SECS_social_9)
data$SECS_extremism_social_10 = abs(50 - data$SECS_social_10) 
data$SECS_extremism_social_13 = abs(50 - data$SECS_social_13) 
data$SECS_extremism_social_14 = abs(50 - data$SECS_social_14)

data$SECS_extremism_economic_2 = abs(50 - data$SECS_economic_2) 
data$SECS_extremism_economic_5 = abs(50 - data$SECS_economic_5) 
data$SECS_extremism_economic_8 = abs(50 - data$SECS_economic_8)
data$SECS_extremism_economic_11 = abs(50 - data$SECS_economic_11) 
data$SECS_extremism_economic_12 = abs(50 - data$SECS_economic_12)

# Calculate mean scores of the scales
data$pseudo_profound_bullshit <- rowMeans(select(data, starts_with("PPBRS")))
data$scientific_bullshit <- rowMeans(select(data, starts_with("SBR_bullshit")))
data$scientific_facts <- rowMeans(select(data, starts_with("SBR_fact")))
data$belief_in_science <- rowMeans(select(data, starts_with("BS")))
data$social_conservatism <- rowMeans(select(data, starts_with("SECS_social")))
data$economic_conservatism <- rowMeans(select(data, starts_with("SECS_economic")))

data$faith_in_intuition <- rowMeans(select(data, starts_with("FI_")))
data$need_for_cognition <- rowMeans(select(data, starts_with("NFC_")))

data$openness <- rowMeans(select(data, starts_with("BFI_O")))
data$extraversion <- rowMeans(select(data, starts_with("BFI_C")))
data$conscientiousness <- rowMeans(select(data, starts_with("BFI_E")))
data$agreeableness <- rowMeans(select(data, starts_with("BFI_A")))
data$neuroticism <- rowMeans(select(data, starts_with("BFI_N")))

# Calculate political extremism scores
data$social_conservatism_extremism <- rowMeans(select(data, starts_with("SECS_extremism_social")))
data$economic_conservatism_extremism <- rowMeans(select(data, 
                                                        starts_with("SECS_extremism_economic")))

# Calculate acquiescence bias
data$acquiescence <- rowMeans(select(data, ends_with("positive"))) - 
  rowMeans(select(data, ends_with("negative")))

# Calculate a scientific bullshit detection score
data$scientific_bullshit_detection <- data$scientific_facts - data$scientific_bullshit

# Create labels for some of the variables
data$gender <- factor(data$gender, labels = c("male", "female", "other"))
data$education <- factor(data$education, 
                         labels = c("some high school", "high school diploma or equivalent", 
                                    "some college", "college degree", "some graduate school",
                                    "graduate degree"))
data$income <- factor(data$income, labels = c("less than $10,000 per year", "$10,001 - $25,000",
                                              "$25,001 - $40,000", "$40,001 - $55,000",
                                              "$55,001 - $70,000", "$70,001 - $85,000",
                                              "$85,001 - $100,000", "over $100,000"))
data$political_orientation <- factor(data$political_orientation, 
                                     labels = c("democrat", "republican", "libertarian", 
                                                "independent", "other"))

# Save data -----------------------------------------------------------------------------------

write_csv(data, "Data/prepared data study 2.csv", na = "")
