
# Setup -------------------------------------------------------------------

# Load packages
library(tidyverse)

# Read data
data <- read_csv("Data/Scientific+BS+Study+3_November+17%2C+2018_10.30.csv")

# Prepare data ------------------------------------------------------------

# Remove testing data
data <- filter(data, Status == 0)

# Create an ID variable
data <- mutate(data, ID = 1:nrow(data))

# Remove variables that are not of interest
data <- select(data, -Status, -IPAddress, -Progress, -Finished, -RecordedDate, 
  -ResponseId, -RecipientLastName, -RecipientFirstName, -RecipientEmail, 
  -ExternalReference, -LocationLatitude, -LocationLongitude, 
  -DistributionChannel, -UserLanguage, -prolific)

# Rename variables
data <- data %>%
  rename(
    start_date = StartDate,
    end_date = EndDate,
    duration = `Duration (in seconds)`,
    
    SECS_social_1 = SECS_1,
    SECS_social_6 = SECS_6,
    SECS_social_7 = SECS_7,
    SECS_social_9 = SECS_9,
    SECS_social_10 = SECS_10,
    SECS_social_13 = SECS_13,
    SECS_social_14 = SECS_14,
    
    SECS_economic_2 = SECS_2,
    SECS_economic_5 = SECS_5,
    SECS_economic_8 = SECS_8,
    SECS_economic_11 = SECS_11,
    SECS_economic_12 = SECS_12,
    
    attention_check_1 = att_check_1,
    attention_check_2 = att_check_2,
    attention_check_3 = att_check_3,
    
    gender = Gender,
    age = Age,
    ethnicity = ethnic,
    education = edu,
    comments = cmmnts
  )

names(data) <- str_replace(names(data), "PPBRS_", "PPBR_")
names(data) <- str_replace(names(data), "SBR_Bull", "SBR")
names(data) <- str_replace(names(data), "BSS_BSS", "BS")
names(data) <- str_replace(names(data), "LIT", "SL")

# Determine whether the science literacy responses were correct
data <- mutate(data,
  SL_correct_1 = ifelse(SL_1 == 1, 1, 0),
  SL_correct_2 = ifelse(SL_2 == 2, 1, 0),
  SL_correct_3 = ifelse(SL_3 == 2, 1, 0),
  SL_correct_4 = ifelse(SL_4 == 1, 1, 0),
  SL_correct_5 = ifelse(SL_5 == 1, 1, 0),
  SL_correct_6 = ifelse(SL_6 == 1, 1, 0),
  SL_correct_7 = ifelse(SL_7 == 2, 1, 0))

# Reverse score some items of social economic conservatism scale
data <- mutate(data,
  SECS_social_1_r = 100 - SECS_social_1,
  SECS_economic_2_r = 100 - SECS_economic_2
  )

# Remove the non-reverse scored items
data <- select(data, -SECS_social_1, -SECS_economic_2)

# Create extremism responses for the political conservatism measures
data <- mutate(data,
  SECS_extremism_social_1 = abs(50 - SECS_social_1_r),
  SECS_extremism_social_6 = abs(50 - SECS_social_6),
  SECS_extremism_social_7 = abs(50 - SECS_social_7),
  SECS_extremism_social_9 = abs(50 - SECS_social_9),
  SECS_extremism_social_10 = abs(50 - SECS_social_10), 
  SECS_extremism_social_13 = abs(50 - SECS_social_13),
  SECS_extremism_social_14 = abs(50 - SECS_social_14),
  
  SECS_extremism_economic_2 = abs(50 - SECS_economic_2_r), 
  SECS_extremism_economic_5 = abs(50 - SECS_economic_5), 
  SECS_extremism_economic_8 = abs(50 - SECS_economic_8),
  SECS_extremism_economic_11 = abs(50 - SECS_economic_11), 
  SECS_extremism_economic_12 = abs(50 - SECS_economic_12))

# Calculate mean and/or sum scores of the scales
data <- mutate(data,
  pseudo_profound_bullshit = rowMeans(select(data, starts_with("PPBR"))),
  scientific_bullshit = rowMeans(select(data, starts_with("SBR"))),
  belief_in_science = rowMeans(select(data, starts_with("BS"))),
  social_conservatism = rowMeans(select(data, starts_with("SECS_social"))),
  economic_conservatism = rowMeans(select(data, starts_with("SECS_economic"))),
  science_literacy = rowSums(select(data, starts_with("SL_correct"))),
  social_conservatism_extremism = rowMeans(select(data, 
    starts_with("SECS_extremism_social"))),
  economic_conservatism_extremism = rowMeans(select(data, 
    starts_with("SECS_extremism_economic"))))

# Create labels for some of the variables
data <- mutate(data,
  gender = factor(gender, labels = c("male", "female", "other")),
  education = factor(education, labels = c("some high school", 
    "high school diploma or equivalent", "some college", "college degree", 
    "some graduate school", "graduate degree")),
  income = factor(income, labels = c("less than $10,000 per year", 
    "$10,001 - $25,000", "$25,001 - $40,000", "$40,001 - $55,000",
    "$55,001 - $70,000", "$70,001 - $85,000", "$85,001 - $100,000", 
    "over $100,000"))
  )

# Check whether they passed the attention check
data <- mutate(data, attention_check_pass = ifelse(attention_check_1 == 6 & 
      attention_check_2 == 9 & attention_check_3 == 9, 1, 0))

# Convert the age column to numeric (1 participant entered his or her prolific 
# ID)
data <- mutate(data, age = as.numeric(age))

# Save data -----------------------------------------------------------------------------------

write_csv(data, "Data/prepared data study 3.csv", na = "")
